@@ -1,4 +1,4 @@
-# Copyright 2010-2021 The pygit2 contributors
+# Copyright 2010-2024 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -65,12 +65,14 @@ API.
 # Standard Library
 from contextlib import contextmanager
 from functools import wraps
+from typing import Optional, Union
 
 # pygit2
-from ._pygit2 import Oid
+from ._pygit2 import Oid, DiffFile
+from .enums import CheckoutNotify, CheckoutStrategy, CredentialType, StashApplyProgress
 from .errors import check_error, Passthrough
 from .ffi import ffi, C
-from .utils import maybe_string, to_bytes
+from .utils import maybe_string, to_bytes, ptr_to_bytes, StrArray
 
 
 #
@@ -78,8 +80,8 @@ from .utils import maybe_string, to_bytes
 # libgit2, to the Python callbacks. And back.
 #
 
-class Payload:
 
+class Payload:
     def __init__(self, **kw):
         for key, value in kw.items():
             setattr(self, key, value)
@@ -89,6 +91,10 @@ class Payload:
         if error_code == C.GIT_EUSER:
             assert self._stored_exception is not None
             raise self._stored_exception
+        elif self._stored_exception is not None:
+            # A callback mapped to a C function returning void
+            # might still have raised an exception.
+            raise self._stored_exception
 
         check_error(error_code)
 
@@ -125,7 +131,12 @@ class RemoteCallbacks(Payload):
             Progress output from the remote.
         """
 
-    def credentials(self, url, username_from_url, allowed_types):
+    def credentials(
+        self,
+        url: str,
+        username_from_url: Union[str, None],
+        allowed_types: CredentialType,
+    ):
         """
         Credentials callback.  If the remote server requires authentication,
         this function will be called and its return value used for
@@ -142,8 +153,9 @@ class RemoteCallbacks(Payload):
         username_from_url : str or None
             Username extracted from the url, if any.
 
-        allowed_types : int
-            Credential types supported by the remote.
+        allowed_types : CredentialType
+            A combination of CredentialType bitflags representing the
+            credential types supported by the remote.
         """
         raise Passthrough
 
@@ -210,12 +222,92 @@ class RemoteCallbacks(Payload):
         """
 
 
+class CheckoutCallbacks(Payload):
+    """Base class for pygit2 checkout callbacks.
+
+    Inherit from this class and override the callbacks that you want to use
+    in your class, which you can then pass to checkout operations.
+    """
+
+    def __init__(self):
+        super().__init__()
+
+    def checkout_notify_flags(self) -> CheckoutNotify:
+        """
+        Returns a bit mask of the notifications to receive from a checkout
+        (a combination of enums.CheckoutNotify constants).
+
+        By default, if you override `checkout_notify`, all notifications will
+        be enabled. You can fine tune the notification types to enable by
+        overriding `checkout_notify_flags`.
+
+        Please note that the flags are only sampled once when checkout begins.
+        You cannot change the flags while a checkout is in progress.
+        """
+        if type(self).checkout_notify == CheckoutCallbacks.checkout_notify:
+            # If the user hasn't overridden the notify function,
+            # filter out all notifications.
+            return CheckoutNotify.NONE
+        else:
+            # If the user provides their own notify function,
+            # enable all notifications by default.
+            return CheckoutNotify.ALL
+
+    def checkout_notify(
+        self,
+        why: CheckoutNotify,
+        path: str,
+        baseline: Optional[DiffFile],
+        target: Optional[DiffFile],
+        workdir: Optional[DiffFile],
+    ):
+        """
+        Checkout will invoke an optional notification callback for
+        certain cases - you pick which ones via `checkout_notify_flags`.
+
+        Raising an exception from this callback will cancel the checkout.
+        The exception will be propagated back and raised by the
+        Repository.checkout_... call.
+
+        Notification callbacks are made prior to modifying any files on disk,
+        so canceling on any notification will still happen prior to any files
+        being modified.
+        """
+        pass
+
+    def checkout_progress(self, path: str, completed_steps: int, total_steps: int):
+        """
+        Optional callback to notify the consumer of checkout progress.
+        """
+        pass
+
+
+class StashApplyCallbacks(CheckoutCallbacks):
+    """Base class for pygit2 stash apply callbacks.
+
+    Inherit from this class and override the callbacks that you want to use
+    in your class, which you can then pass to stash apply or pop operations.
+    """
+
+    def stash_apply_progress(self, progress: StashApplyProgress):
+        """
+        Stash application progress notification function.
+
+        `progress` is a StashApplyProgress constant.
+
+        Raising an exception from this callback will abort the stash
+        application.
+        """
+        pass
+
+
 #
 # The context managers below wrap the calls to libgit2 functions, which them in
 # turn call to callbacks defined later in this module. These context managers
 # are used in the pygit2 API, see for instance remote.py
 #
 
+
 @contextmanager
 def git_clone_options(payload, opts=None):
     if opts is None:
@@ -245,7 +337,7 @@ def git_fetch_options(payload, opts=None):
 
     if opts is None:
         opts = ffi.new('git_fetch_options *')
-        C.git_fetch_init_options(opts, C.GIT_FETCH_OPTIONS_VERSION)
+        C.git_fetch_options_init(opts, C.GIT_FETCH_OPTIONS_VERSION)
 
     # Plug callbacks
     opts.callbacks.sideband_progress = C._sideband_progress_cb
@@ -269,7 +361,7 @@ def git_push_options(payload, opts=None):
         payload = RemoteCallbacks()
 
     opts = ffi.new('git_push_options *')
-    C.git_push_init_options(opts, C.GIT_PUSH_OPTIONS_VERSION)
+    C.git_push_options_init(opts, C.GIT_PUSH_OPTIONS_VERSION)
 
     # Plug callbacks
     opts.callbacks.sideband_progress = C._sideband_progress_cb
@@ -322,6 +414,7 @@ def git_remote_callbacks(payload):
 # exception.
 #
 
+
 def libgit2_callback(f):
     @wraps(f)
     def wrapper(*args):
@@ -334,7 +427,7 @@ def libgit2_callback(f):
             # then libgit2 will behave as if there was no callback set in the
             # first place.
             return C.GIT_PASSTHROUGH
-        except Exception as e:
+        except BaseException as e:
             # Keep the exception to be re-raised later, and inform libgit2 that
             # the user defined callback has failed.
             data._stored_exception = e
@@ -343,6 +436,26 @@ def libgit2_callback(f):
     return ffi.def_extern()(wrapper)
 
 
+def libgit2_callback_void(f):
+    @wraps(f)
+    def wrapper(*args):
+        data = ffi.from_handle(args[-1])
+        args = args[:-1] + (data,)
+        try:
+            f(*args)
+        except Passthrough:
+            # A user defined callback can raise Passthrough to decline to act;
+            # then libgit2 will behave as if there was no callback set in the
+            # first place.
+            pass  # Function returns void
+        except BaseException as e:
+            # Keep the exception to be re-raised later
+            data._stored_exception = e
+            pass  # Function returns void, so we can't do much here.
+
+    return ffi.def_extern()(wrapper)
+
+
 @libgit2_callback
 def _certificate_cb(cert_i, valid, host, data):
     # We want to simulate what should happen if libgit2 supported pass-through
@@ -373,6 +486,9 @@ def _credentials_cb(cred_out, url, username, allowed, data):
     if not credentials:
         return 0
 
+    # convert int flags to enum before forwarding to user code
+    allowed = CredentialType(allowed)
+
     ccred = get_credentials(credentials, url, username, allowed)
     cred_out[0] = ccred[0]
     return 0
@@ -384,7 +500,7 @@ def _push_update_reference_cb(ref, msg, data):
     if not push_update_reference:
         return 0
 
-    refname = ffi.string(ref)
+    refname = maybe_string(ref)
     message = maybe_string(msg)
     push_update_reference(refname, message)
     return 0
@@ -394,7 +510,9 @@ def _push_update_reference_cb(ref, msg, data):
 def _remote_create_cb(remote_out, repo, name, url, data):
     from .repository import Repository
 
-    remote = data.remote(Repository._from_c(repo, False), ffi.string(name), ffi.string(url))
+    remote = data.remote(
+        Repository._from_c(repo, False), ffi.string(name), ffi.string(url)
+    )
     remote_out[0] = remote._remote
     # we no longer own the C object
     remote._remote = ffi.NULL
@@ -425,7 +543,7 @@ def _sideband_progress_cb(string, length, data):
 
 @libgit2_callback
 def _transfer_progress_cb(stats_ptr, data):
-    from .remote import TransferProgress
+    from .remotes import TransferProgress
 
     transfer_progress = getattr(data, 'transfer_progress', None)
     if not transfer_progress:
@@ -452,9 +570,9 @@ def _update_tips_cb(refname, a, b, data):
 # Other functions, used above.
 #
 
+
 def get_credentials(fn, url, username, allowed):
-    """Call fn and return the credentials object.
-    """
+    """Call fn and return the credentials object."""
     url_str = maybe_string(url)
     username_str = maybe_string(username)
 
@@ -463,43 +581,205 @@ def get_credentials(fn, url, username, allowed):
     credential_type = getattr(creds, 'credential_type', None)
     credential_tuple = getattr(creds, 'credential_tuple', None)
     if not credential_type or not credential_tuple:
-        raise TypeError("credential does not implement interface")
+        raise TypeError('credential does not implement interface')
 
     cred_type = credential_type
 
     if not (allowed & cred_type):
-        raise TypeError("invalid credential type")
+        raise TypeError('invalid credential type')
 
     ccred = ffi.new('git_credential **')
-    if cred_type == C.GIT_CREDENTIAL_USERPASS_PLAINTEXT:
+    if cred_type == CredentialType.USERPASS_PLAINTEXT:
         name, passwd = credential_tuple
-        err = C.git_credential_userpass_plaintext_new(ccred, to_bytes(name),
-                                                      to_bytes(passwd))
+        err = C.git_credential_userpass_plaintext_new(
+            ccred, to_bytes(name), to_bytes(passwd)
+        )
 
-    elif cred_type == C.GIT_CREDENTIAL_SSH_KEY:
+    elif cred_type == CredentialType.SSH_KEY:
         name, pubkey, privkey, passphrase = credential_tuple
         name = to_bytes(name)
         if pubkey is None and privkey is None:
             err = C.git_credential_ssh_key_from_agent(ccred, name)
         else:
-            err = C.git_credential_ssh_key_new(ccred, name, to_bytes(pubkey),
-                                               to_bytes(privkey),
-                                               to_bytes(passphrase))
+            err = C.git_credential_ssh_key_new(
+                ccred, name, to_bytes(pubkey), to_bytes(privkey), to_bytes(passphrase)
+            )
 
-    elif cred_type == C.GIT_CREDENTIAL_USERNAME:
-        name, = credential_tuple
+    elif cred_type == CredentialType.USERNAME:
+        (name,) = credential_tuple
         err = C.git_credential_username_new(ccred, to_bytes(name))
 
-    elif cred_type == C.GIT_CREDENTIAL_SSH_MEMORY:
+    elif cred_type == CredentialType.SSH_MEMORY:
         name, pubkey, privkey, passphrase = credential_tuple
         if pubkey is None and privkey is None:
-            raise TypeError("SSH keys from memory are empty")
-        err = C.git_credential_ssh_key_memory_new(ccred, to_bytes(name),
-                                                  to_bytes(pubkey), to_bytes(privkey),
-                                                  to_bytes(passphrase))
+            raise TypeError('SSH keys from memory are empty')
+        err = C.git_credential_ssh_key_memory_new(
+            ccred,
+            to_bytes(name),
+            to_bytes(pubkey),
+            to_bytes(privkey),
+            to_bytes(passphrase),
+        )
     else:
-        raise TypeError("unsupported credential type")
+        raise TypeError('unsupported credential type')
 
     check_error(err)
 
     return ccred
+
+
+#
+# Checkout callbacks
+#
+
+
+@libgit2_callback
+def _checkout_notify_cb(
+    why, path_cstr, baseline, target, workdir, data: CheckoutCallbacks
+):
+    pypath = maybe_string(path_cstr)
+    pybaseline = DiffFile.from_c(ptr_to_bytes(baseline))
+    pytarget = DiffFile.from_c(ptr_to_bytes(target))
+    pyworkdir = DiffFile.from_c(ptr_to_bytes(workdir))
+
+    try:
+        data.checkout_notify(why, pypath, pybaseline, pytarget, pyworkdir)
+    except Passthrough:
+        # Unlike most other operations with optional callbacks, checkout
+        # doesn't support the GIT_PASSTHROUGH return code, so we must bypass
+        # libgit2_callback's error handling and return 0 explicitly here.
+        pass
+
+    # If the user's callback has raised any other exception type,
+    # it's caught by the libgit2_callback decorator by now.
+    # So, return success code to libgit2.
+    return 0
+
+
+@libgit2_callback_void
+def _checkout_progress_cb(path, completed_steps, total_steps, data: CheckoutCallbacks):
+    data.checkout_progress(maybe_string(path), completed_steps, total_steps)
+
+
+def _git_checkout_options(
+    callbacks=None,
+    strategy=None,
+    directory=None,
+    paths=None,
+    c_checkout_options_ptr=None,
+):
+    if callbacks is None:
+        payload = CheckoutCallbacks()
+    else:
+        payload = callbacks
+
+    # Get handle to payload
+    handle = ffi.new_handle(payload)
+
+    # Create the options struct to pass
+    if not c_checkout_options_ptr:
+        opts = ffi.new('git_checkout_options *')
+    else:
+        opts = c_checkout_options_ptr
+    check_error(C.git_checkout_options_init(opts, 1))
+
+    # References we need to keep to strings and so forth
+    refs = [handle]
+
+    # pygit2's default is SAFE | RECREATE_MISSING
+    if strategy is None:
+        strategy = CheckoutStrategy.SAFE | CheckoutStrategy.RECREATE_MISSING
+    opts.checkout_strategy = int(strategy)
+
+    if directory:
+        target_dir = ffi.new('char[]', to_bytes(directory))
+        refs.append(target_dir)
+        opts.target_directory = target_dir
+
+    if paths:
+        strarray = StrArray(paths)
+        refs.append(strarray)
+        opts.paths = strarray.ptr[0]
+
+    # If we want to receive any notifications, set up notify_cb in the options
+    notify_flags = payload.checkout_notify_flags()
+    if notify_flags != CheckoutNotify.NONE:
+        opts.notify_cb = C._checkout_notify_cb
+        opts.notify_flags = int(notify_flags)
+        opts.notify_payload = handle
+
+    # Set up progress callback if the user has provided their own
+    if type(payload).checkout_progress != CheckoutCallbacks.checkout_progress:
+        opts.progress_cb = C._checkout_progress_cb
+        opts.progress_payload = handle
+
+    # Give back control
+    payload.checkout_options = opts
+    payload._ffi_handle = handle
+    payload._refs = refs
+    payload._stored_exception = None
+    return payload
+
+
+@contextmanager
+def git_checkout_options(callbacks=None, strategy=None, directory=None, paths=None):
+    yield _git_checkout_options(
+        callbacks=callbacks, strategy=strategy, directory=directory, paths=paths
+    )
+
+
+#
+# Stash callbacks
+#
+
+
+@libgit2_callback
+def _stash_apply_progress_cb(progress: StashApplyProgress, data: StashApplyCallbacks):
+    try:
+        data.stash_apply_progress(progress)
+    except Passthrough:
+        # Unlike most other operations with optional callbacks, stash apply
+        # doesn't support the GIT_PASSTHROUGH return code, so we must bypass
+        # libgit2_callback's error handling and return 0 explicitly here.
+        pass
+
+    # If the user's callback has raised any other exception type,
+    # it's caught by the libgit2_callback decorator by now.
+    # So, return success code to libgit2.
+    return 0
+
+
+@contextmanager
+def git_stash_apply_options(
+    callbacks=None, reinstate_index=False, strategy=None, directory=None, paths=None
+):
+    if callbacks is None:
+        callbacks = StashApplyCallbacks()
+
+    # Set up stash options
+    stash_apply_options = ffi.new('git_stash_apply_options *')
+    check_error(C.git_stash_apply_options_init(stash_apply_options, 1))
+
+    flags = reinstate_index * C.GIT_STASH_APPLY_REINSTATE_INDEX
+    stash_apply_options.flags = flags
+
+    # Now set up checkout options
+    c_checkout_options_ptr = ffi.addressof(stash_apply_options.checkout_options)
+    payload = _git_checkout_options(
+        callbacks=callbacks,
+        strategy=strategy,
+        directory=directory,
+        paths=paths,
+        c_checkout_options_ptr=c_checkout_options_ptr,
+    )
+    assert payload == callbacks
+    assert payload.checkout_options == c_checkout_options_ptr
+
+    # Set up stash progress callback if the user has provided their own
+    if type(callbacks).stash_apply_progress != StashApplyCallbacks.stash_apply_progress:
+        stash_apply_options.progress_cb = C._stash_apply_progress_cb
+        stash_apply_options.progress_payload = payload._ffi_handle
+
+    # Give back control
+    payload.stash_apply_options = stash_apply_options
+    yield payload
